@@ -1,13 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
-from trytond.model import (ModelView, ModelSQL, ModelSingleton, ValueMixin,
-    fields)
-from trytond.pool import Pool
-from trytond.pyson import Eval, Id
-from trytond.tools.multivalue import migrate_property
+from trytond.model import (
+    ModelSingleton, ModelSQL, ModelView, ValueMixin, fields)
 from trytond.modules.company.model import (
     CompanyMultiValueMixin, CompanyValueMixin)
+from trytond.pool import Pool
+from trytond.pyson import Eval, Id, TimeDelta
 
 sale_invoice_method = fields.Selection(
     'get_sale_invoice_methods', "Sale Invoice Method")
@@ -48,7 +46,12 @@ class Configuration(
     get_sale_invoice_methods = get_sale_methods('invoice_method')
     sale_shipment_method = fields.MultiValue(sale_shipment_method)
     get_sale_shipment_methods = get_sale_methods('shipment_method')
-    sale_process_after = fields.TimeDelta("Process Sale after",
+    sale_process_after = fields.TimeDelta(
+        "Process Sale after",
+        domain=['OR',
+            ('sale_process_after', '=', None),
+            ('sale_process_after', '>=', TimeDelta()),
+            ],
         help="The grace period during which confirmed sale "
         "can still be reset to draft.\n"
         "Applied if a worker queue is activated.")
@@ -75,26 +78,7 @@ class ConfigurationSequence(ModelSQL, CompanyValueMixin):
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
             ('sequence_type', '=', Id('sale', 'sequence_type_sale')),
-            ],
-        depends=['company'])
-
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(ConfigurationSequence, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.append('sale_sequence')
-        value_names.append('sale_sequence')
-        fields.append('company')
-        migrate_property(
-            'sale.configuration', field_names, cls, value_names,
-            fields=fields)
+            ])
 
     @classmethod
     def default_sale_sequence(cls):
@@ -114,23 +98,6 @@ class ConfigurationSaleMethod(ModelSQL, ValueMixin):
     sale_shipment_method = sale_shipment_method
     get_sale_shipment_methods = get_sale_methods('shipment_method')
 
-    @classmethod
-    def __register__(cls, module_name):
-        exist = backend.TableHandler.table_exist(cls._table)
-
-        super(ConfigurationSaleMethod, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.extend(['sale_invoice_method', 'sale_shipment_method'])
-        value_names.extend(['sale_invoice_method', 'sale_shipment_method'])
-        migrate_property(
-            'sale.configuration', field_names, cls, value_names,
-            fields=fields)
-
     @classmethod
     def default_sale_invoice_method(cls):
         return 'order'
